@@ -11,7 +11,7 @@ def get_local_file_path():
     'Determine a consistent local file path'
     local_dir = Path(__file__).resolve().parent / ".cache"
     os.makedirs(local_dir, exist_ok=True)
-    return local_dir / 'TESS_FFI_times.csv'
+    return local_dir / 'tess_orbit_time.csv'
 
 
 
